<p align="center">
  <a>
    <img src="https://i.ibb.co/CHJ3Ws1/Py-Toast-JPG.jpg" alt="Py-Toast-JPG" border="0">
    <br>
    <br>
    <img src="https://forthebadge.com/images/badges/oooo-kill-em.svg">
    <img src="https://forthebadge.com/images/badges/made-with-crayons.svg">
    <img src="https://forthebadge.com/images/badges/no-ragrets.svg">
  </a>
</p>
<p align="center">
    The one and only cross-platform Toaster/Notification in python.
</p>

```
from creed import Notif

Notif(title="Python", message="Hello, World", duration=20).Toast()
```